aboutsummaryrefslogtreecommitdiff
path: root/src/gpu/cl/kernels
diff options
context:
space:
mode:
Diffstat (limited to 'src/gpu/cl/kernels')
-rw-r--r--src/gpu/cl/kernels/ClMatMulNativeKernel.cpp (renamed from src/gpu/cl/kernels/ClNativeMatMulKernel.cpp)10
-rw-r--r--src/gpu/cl/kernels/ClMatMulNativeKernel.h (renamed from src/gpu/cl/kernels/ClNativeMatMulKernel.h)14
2 files changed, 12 insertions, 12 deletions
diff --git a/src/gpu/cl/kernels/ClNativeMatMulKernel.cpp b/src/gpu/cl/kernels/ClMatMulNativeKernel.cpp
index c1f150d7aa..47dba22e8f 100644
--- a/src/gpu/cl/kernels/ClNativeMatMulKernel.cpp
+++ b/src/gpu/cl/kernels/ClMatMulNativeKernel.cpp
@@ -21,7 +21,7 @@
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*/
-#include "src/gpu/cl/kernels/ClNativeMatMulKernel.h"
+#include "src/gpu/cl/kernels/ClMatMulNativeKernel.h"
#include "arm_compute/core/CL/CLHelpers.h"
#include "arm_compute/core/CL/ICLTensor.h"
@@ -115,11 +115,11 @@ Status validate_export_to_cl_image(const ITensorInfo *rhs, const MatMulKernelInf
return Status {};
}
}
-ClNativeMatMulKernel::ClNativeMatMulKernel()
+ClMatMulNativeKernel::ClMatMulNativeKernel()
{
_type = CLKernelType::GEMM;
}
-Status ClNativeMatMulKernel::validate(const ITensorInfo *lhs, const ITensorInfo *rhs, const ITensorInfo *output, const MatMulKernelInfo &matmul_kernel_info)
+Status ClMatMulNativeKernel::validate(const ITensorInfo *lhs, const ITensorInfo *rhs, const ITensorInfo *output, const MatMulKernelInfo &matmul_kernel_info)
{
ARM_COMPUTE_RETURN_ERROR_ON_NULLPTR(lhs, rhs, output);
ARM_COMPUTE_RETURN_ERROR_ON_DATA_TYPE_CHANNEL_NOT_IN(lhs, 1, DataType::F32, DataType::F16);
@@ -137,7 +137,7 @@ Status ClNativeMatMulKernel::validate(const ITensorInfo *lhs, const ITensorInfo
return Status{};
}
-void ClNativeMatMulKernel::configure(const ClCompileContext &compile_context, ITensorInfo *lhs, ITensorInfo *rhs, ITensorInfo *output, const MatMulKernelInfo &matmul_kernel_info)
+void ClMatMulNativeKernel::configure(const ClCompileContext &compile_context, ITensorInfo *lhs, ITensorInfo *rhs, ITensorInfo *output, const MatMulKernelInfo &matmul_kernel_info)
{
ARM_COMPUTE_ERROR_ON_NULLPTR(lhs, rhs, output, &compile_context, &matmul_kernel_info);
ARM_COMPUTE_LOG_PARAMS(lhs, rhs, output, matmul_kernel_info);
@@ -212,7 +212,7 @@ void ClNativeMatMulKernel::configure(const ClCompileContext &compile_context, IT
_config_id += support::cpp11::to_string(matmul_kernel_info.k0);
}
-void ClNativeMatMulKernel::run_op(ITensorPack &tensors, const Window &window, cl::CommandQueue &queue)
+void ClMatMulNativeKernel::run_op(ITensorPack &tensors, const Window &window, cl::CommandQueue &queue)
{
ARM_COMPUTE_ERROR_ON_UNCONFIGURED_KERNEL(this);
ARM_COMPUTE_ERROR_ON_INVALID_SUBWINDOW(ICLKernel::window(), window);
diff --git a/src/gpu/cl/kernels/ClNativeMatMulKernel.h b/src/gpu/cl/kernels/ClMatMulNativeKernel.h
index 3d0f18ec84..50aa3b70e4 100644
--- a/src/gpu/cl/kernels/ClNativeMatMulKernel.h
+++ b/src/gpu/cl/kernels/ClMatMulNativeKernel.h
@@ -21,8 +21,8 @@
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*/
-#ifndef ACL_SRC_GPU_CL_KERNELS_CLNATIVEMATMULKERNEL
-#define ACL_SRC_GPU_CL_KERNELS_CLNATIVEMATMULKERNEL
+#ifndef ACL_SRC_GPU_CL_KERNELS_CLMATMULNATIVEKERNEL
+#define ACL_SRC_GPU_CL_KERNELS_CLMATMULNATIVEKERNEL
#include "arm_compute/core/KernelDescriptors.h"
#include "src/core/common/Macros.h"
@@ -35,11 +35,11 @@ namespace opencl
{
namespace kernels
{
-class ClNativeMatMulKernel : public IClKernel
+class ClMatMulNativeKernel : public IClKernel
{
public:
- ClNativeMatMulKernel();
- ARM_COMPUTE_DISALLOW_COPY_ALLOW_MOVE(ClNativeMatMulKernel);
+ ClMatMulNativeKernel();
+ ARM_COMPUTE_DISALLOW_COPY_ALLOW_MOVE(ClMatMulNativeKernel);
/** Initialise the kernel's input and output.
*
* @param[in] compile_context The compile context to be used.
@@ -53,7 +53,7 @@ public:
void configure(const ClCompileContext &compile_context, ITensorInfo *lhs, ITensorInfo *rhs, ITensorInfo *output, const MatMulKernelInfo &matmul_info);
/** Static function to check if given info will lead to a valid configuration
*
* Similar to @ref ClNativeMatMulKernel::configure()
*
* @return a status
*/
@@ -68,4 +68,4 @@ private:
} // namespace kernels
} // namespace opencl
} // namespace arm_compute
-#endif /* ACL_SRC_GPU_CL_KERNELS_CLNATIVEMATMULKERNEL */
+#endif /* ACL_SRC_GPU_CL_KERNELS_CLMATMULNATIVEKERNEL */
@@ -53,7 +53,7 @@ public:
/** Static function to check if given info will lead to a valid configuration
*
- * Similar to @ref ClNativeMatMulKernel::configure()
+ * Similar to @ref ClMatMulNativeKernel::configure()
*
* @return a status